@@ -24,35 +24,16 @@
 
 #include <KConfig>
 #include <KDebug>
-#include <KLocale>
-#include <KGlobal>
-#include <KNotificationRestrictions>
 #include <KToolBar>
 
-#include <QContextMenuEvent>
-#include <QToolButton>
-#include <QDBusInterface>
-#include <QDBusReply>
-
-#include <solid/powermanagement.h>
-
 #include "actions.h"
-#include "adjustSizeButton.h"
 #include "theStream.h"
 #include "videoWindow.h"
 
-
-//TODO do in Sconstruct
 #define QT_FATAL_ASSERT
 
-
-//TODO make the XineEngine into xine::Stream and then make singleton and add functions like Stream::hasVideo() etc.
-//TODO make convenience function to get fullscreen state
-
-
 namespace Dragon {
 
-
 void
 MainWindow::engineStateChanged( Phonon::State state, Phonon::State oldstate )
 {
@@ -82,10 +63,8 @@ MainWindow::engineStateChanged( Phonon::State state, Phonon::State oldstate )
         break;
     }
 
-//     using namespace Engine;
-
     bool enable = false;
-    if(state == Phonon::PlayingState || state == Phonon::PausedState)
+    if(state == Phonon::PlayingState || state == Phonon::PausedState || state == Phonon::BufferingState)
     {
       enable = true;
     }
@@ -107,8 +86,8 @@ MainWindow::engineStateChanged( Phonon::State state, Phonon::State oldstate )
         // is disabled if we are empty, this looks more sensible
         PlayAction* playAction = static_cast<PlayAction*>( actionCollection()->action(QLatin1String( "play" )) );
         playAction->setEnabled( hasMedia );
-        playAction->setPlaying( state == Phonon::PlayingState );
-        actionCollection()->action(QLatin1String( "aspect_ratio_menu" ))->setEnabled(( state == Phonon::PlayingState || state == Phonon::PausedState) && TheStream::hasVideo() );
+        playAction->setPlaying( state == Phonon::PlayingState || state == Phonon::BufferingState );
+        actionCollection()->action(QLatin1String( "aspect_ratio_menu" ))->setEnabled((enable) && TheStream::hasVideo() );
 
         // set correct aspect ratio
         if( state != Phonon::LoadingState )
@@ -118,24 +97,9 @@ MainWindow::engineStateChanged( Phonon::State state, Phonon::State oldstate )
 
     /// turn off screensaver
     if( state == Phonon::PlayingState )
-    {
-      m_stopSleepCookie = Solid::PowerManagement::beginSuppressingSleep(QLatin1String( "watching a film" ));
-      m_stopScreenPowerMgmtCookie = Solid::PowerManagement::beginSuppressingScreenPowerManagement(QLatin1String( "watching a film" ));
-      if (!m_stopScreenSaver)
-          m_stopScreenSaver = new KNotificationRestrictions(KNotificationRestrictions::ScreenSaver);
-    }
+        inhibitPowerSave();
     else if( Phonon::StoppedState || !TheStream::hasMedia() )
-    {
-      //stop supressing sleep
-      Solid::PowerManagement::stopSuppressingSleep(m_stopSleepCookie);
-
-      //stop supressing screen power management
-      Solid::PowerManagement::stopSuppressingScreenPowerManagement(m_stopScreenPowerMgmtCookie);
-
-     //stop disabling screensaver
-      delete m_stopScreenSaver; // It is always 0, I have been careful.
-      m_stopScreenSaver = 0;
-    }
+        releasePowerSave();
 
     updateTitleBarText();
 
@@ -157,30 +121,6 @@ MainWindow::engineStateChanged( Phonon::State state, Phonon::State oldstate )
         }
         action("toggle_dvd_menu")->setEnabled( false );
     }
-    if( isFullScreen && !toolbar->testAttribute( Qt::WA_UnderMouse ) )
-    {/*
-        switch( state ) {
-        case Engine::TrackEnded:
-            toolbar->show();
-
-            if( videoWindow()->isActiveWindow() ) {
-                //FIXME dual-screen this seems to still show
-                QContextMenuEvent e( QContextMenuEvent::Other, QPoint() );
-                QApplication::sendEvent( videoWindow(), &e );
-            }
-            break;
-        case Engine::Empty:
-        case Engine::Paused:
-        case Engine::Uninitialised:
-            toolBar()->show();
-            break;
-        case Phonon::PlayingState:
-            toolBar()->hide();
-            break;
-        case Engine::Loaded:
-            break;
-        }*/
-    }
 }//engineStateChanged
 
 
